@@ -448,16 +448,16 @@ impl Session {
         // a null pointer is returned
         let ses_ptr = unsafe { ffi::auth_userchallenge(name_ptr, style_ptr, type_ptr, &mut challenge_ptr) };
     
-        if challenge_ptr == std::ptr::null_mut() {
-            return Err(Error::UserChallenge);
-        }
-    
-        // safety: with the null check above, the challenge pointer should
-        // point to a valid C string
-        let challenge = unsafe {
-            std::ffi::CString::from_raw(challenge_ptr)
-            .to_str()?
-            .to_string()
+        let challenge = if challenge_ptr == std::ptr::null_mut() {
+           format!("doas passphrase for {}: ", name) 
+        } else {
+            // safety: with the null check above, the challenge pointer should
+            // point to a valid C string
+            unsafe {
+                std::ffi::CString::from_raw(challenge_ptr)
+                .to_str()?
+                .to_string()
+            }
         };
 
         // safety: challenge pointer checked for null above, and points
